@@ -3,15 +3,11 @@ import json
 import os
 import logging
 import requests
-import socket
 import pandas as pd
 from IPython.display import HTML
 
 logger = logging.getLogger(__name__)
 
-HOST_IP = socket.gethostbyname(socket.gethostname())
-PORT = 9000
-
 STATUS = "status"
 RESULT = "result"
 ERROR = "error"
@@ -27,13 +23,12 @@ QUERY_SHOW_TABLES = """show tables in {schema_name};"""
 QUERY_TABLE_RECORDS_WITH_LIMIT = """select * from {schema_name}.{table_name} limit {limit};"""
 QUERY_TABLE_RECORDS = """select * from {schema_name}.{table_name} limit 100;"""
 
-SERVICE_URL = f"http://{HOST_IP}:{PORT}"
 # Athena services
-API_VALIDATE_USER = "/ccf/services/validate_user"
-API_GET_ATHENA_DATABASES = "/ccf/services/get_athena_databases"
-API_GET_ATHENA_TABLES = "/ccf/services/get_athena_tables"
-API_QUERY_ATHENA_TABLE = "/ccf/services/query_athena_table"
-API_RUN_QUERY_ON_ATHENA = "/ccf/services/run_query_on_athena"
+API_VALIDATE_USER = "/ccf/services/v2.0/validate_user"
+API_GET_ATHENA_DATABASES = "/ccf/services/v2.0/get_athena_databases"
+API_GET_ATHENA_TABLES = "/ccf/services/v2.0/get_athena_tables"
+API_QUERY_ATHENA_TABLE = "/ccf/services/v2.0/query_athena_table"
+API_RUN_QUERY_ON_ATHENA = "/ccf/services/v2.0/run_query_on_athena"
 
 HEADERS = {
     'content-type': "application/json",
@@ -57,7 +52,7 @@ class AthenaClient:
         self._user_name = os.getenv(self._USER_NAME, None)
         self._access_token = os.getenv(self._ACCESS_TOKEN, None)
         self._user_role = os.getenv(self._USER_ROLE, None)
-        self._ccf_services_host = os.getenv(self._CCF_SERVICES_HOST, None) or SERVICE_URL
+        self._ccf_services_host = os.getenv(self._CCF_SERVICES_HOST, None)
 
     def connect(self):
         # TODO - Add user validation
